#!/bin/bash
# PineappleEA download script by ich777 for SteamDeck

DATA_DIR=/opt/Yuzu

LAT_V="$(wget -qO- https://api.github.com/repos/pineappleEA/pineapple-src/releases/latest | grep tag_name | cut -d '"' -f4 | cut -d 'v' -f2)"
CUR_V="$(find ${DATA_DIR}/ -maxdepth 1 -type f -name "Linux-Yuzu*" | sort -V | tail -1 | rev | cut -d '/' -f1 | rev | cut -d '-' -f3- | cut -d '.' -f1)"

if [ -z ${LAT_V} ]; then
  echo "Couldn't get latest version from Yuzu EA!"
  if [ -z ${CUR_V} ]; then
    echo "No current version from Yuzu EA found, start failed!"
    exit 1
  else
    echo "Setting current installed version to latest version!"
    LAT_V="${CUR_V}"
  fi
fi

if [ ! -d ${DATA_DIR} ]; then
  mkdir -p ${DATA_DIR}
fi

if [ -z "${CUR_V}" ]; then
  echo "Yuzu EA not found, downloading and installing ${LAT_V}..."
  cd ${DATA_DIR}
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage "https://github.com/pineappleEA/pineapple-src/releases/download/${LAT_V}/Linux-Yuzu-${LAT_V}.AppImage" ; then
    echo "Successfully downloaded Yuzu EA ${LAT_V}"
  else
    echo "Something went wrong, can't download Yuzu ${LAT_V}!"
    rm -r ${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage
    exit 1
  fi
elif [ "${CUR_V}" != "${LAT_V}" ]; then
  echo "Version missmatch, installed ${CUR_V}, downloading and installing v${LAT_V}..."
  cd ${DATA_DIR}
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage "https://github.com/pineappleEA/pineapple-src/releases/download/${LAT_V}/Linux-Yuzu-${LAT_V}.AppImage" ; then
    echo "Successfully downloaded Yuzu EA ${LAT_V}"
    rm -f $(ls ${DATA_DIR}/Linux-Yuzu-*.AppImage 2>/dev/null | grep -v "${LAT_V}")
  else
    echo "Something went wrong, can't download Yuzu ${LAT_V} continuing with ${CUR_V}!"
    rm -r ${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage
    LAT_V="${CUR_V}"
  fi
elif [ "${CUR_V}" == "${LAT_V}" ]; then
  echo "Yuzu ${CUR_V} up-to-date"
fi

echo "Starting Yuzu ${LAT_V}"
chmod +x ${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage
${DATA_DIR}/Linux-Yuzu-${LAT_V}.AppImage "$@"
