#!/bin/bash

DATA_DIR=/opt/Heroic

LAT_V="$(wget -qO- https://api.github.com/repos/Heroic-Games-Launcher/HeroicGamesLauncher/releases/latest | grep tag_name | cut -d '"' -f4 | cut -d 'v' -f2)"
CUR_V="$(find ${DATA_DIR}/ -maxdepth 1 -type f -name "HeroicVersion*" | rev | cut -d '-' -f1 | rev)"

if [ -z ${LAT_V} ]; then
  echo "Couldn't get latest version from Heroic!"
  if [ -z ${CUR_V} ]; then
    echo "No current version from Heroic found, start failed!"
    exit 1
  else
    echo "Setting current installed version to latest version!"
    LAT_V="${CUR_V}"
  fi
fi

if [ ! -d ${DATA_DIR} ]; then
  mkdir -p ${DATA_DIR}
fi

rm -f ${DATA_DIR}/Heroic-*.tar.xz

if [ -z "${CUR_V}" ]; then
  echo "Heroic not found, downloading and installing ${LAT_V}..."
  cd ${DATA_DIR}
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Heroic-${LAT_V}.tar.xz "https://github.com/Heroic-Games-Launcher/HeroicGamesLauncher/releases/download/v${LAT_V}/heroic-${LAT_V}.tar.xz" ; then
    echo "Successfully downloaded Heroic ${LAT_V}"
  else
    echo "Something went wrong, can't download Heroic ${LAT_V}!"
    rm -f ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
    exit 1
  fi
  tar -C ${DATA_DIR}/ --strip-components=1 -xf ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
  rm -f ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
  touch ${DATA_DIR}/HeroicVersion-${LAT_V}
elif [ "${CUR_V}" != "${LAT_V}" ]; then
  echo "Version missmatch, installed ${CUR_V}, downloading and installing v${LAT_V}..."
  cd ${DATA_DIR}
  rm -f ${DATA_DIR}/HeroicVersion*
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Heroic-${LAT_V}.tar.xz "https://github.com/Heroic-Games-Launcher/HeroicGamesLauncher/releases/download/v${LAT_V}/heroic-${LAT_V}.tar.xz" ; then
    echo "Successfully downloaded Heroic ${LAT_V}"
  else
    echo "Something went wrong, can't download Heroic ${LAT_V} continuing with ${CUR_V}!"
    rm -r ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
    LAT_V="${CUR_V}"
    touch ${DATA_DIR}/HeroicVersion-${LAT_V}
    ERROR=true
  fi
  if [ "${ERROR}" != "true" ]; then
    tar -C ${DATA_DIR}/ --strip-components=1 -xf ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
    rm -f ${DATA_DIR}/Heroic-${LAT_V}.tar.xz
    touch ${DATA_DIR}/HeroicVersion-${LAT_V}
  fi
elif [ "${CUR_V}" == "${LAT_V}" ]; then
  echo "Heroic ${CUR_V} up-to-date"
fi

echo "Starting Heroic ${LAT_V}"
chmod +x ${DATA_DIR}/Heroic
${DATA_DIR}/heroic "$@"
