#!/bin/bash

DATA_DIR=/opt/Ryujinx

LAT_V="$(wget -qO- https://api.github.com/repos/Ryujinx/release-channel-master/releases/latest | grep tag_name | cut -d '"' -f4 | cut -d 'v' -f2)"
CUR_V="$(find ${DATA_DIR}/ -maxdepth 1 -type f -name "RyujinxVersion*" | rev | cut -d '-' -f1 | rev)"

if [ -z ${LAT_V} ]; then
  echo "Couldn't get latest version from Ryujinx!"
  if [ -z ${CUR_V} ]; then
    echo "No current version from Ryujinx found, start failed!"
    exit 1
  else
    echo "Setting current installed version to latest version!"
    LAT_V="${CUR_V}"
  fi
fi

if [ ! -d ${DATA_DIR} ]; then
  mkdir -p ${DATA_DIR}
fi

rm -f ${DATA_DIR}/Ryujinx-*.tar.gz

if [ -z "${CUR_V}" ]; then
  echo "Ryujinx not found, downloading and installing ${LAT_V}..."
  cd ${DATA_DIR}
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz "https://github.com/Ryujinx/release-channel-master/releases/download/${LAT_V}/ryujinx-${LAT_V}-linux_x64.tar.gz" ; then
    echo "Successfully downloaded Ryujinx ${LAT_V}"
  else
    echo "Something went wrong, can't download Ryujinx ${LAT_V}!"
    rm -f ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
    exit 1
  fi
  tar -C ${DATA_DIR}/ --strip-components=1 -xf ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
  rm -f ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
  touch ${DATA_DIR}/RyujinxVersion-${LAT_V}
elif [ "${CUR_V}" != "${LAT_V}" ]; then
  echo "Version missmatch, installed ${CUR_V}, downloading and installing v${LAT_V}..."
  cd ${DATA_DIR}
  rm -f ${DATA_DIR}/RyujinxVersion*
  if wget -q -nc --show-progress --progress=bar:force:noscroll -O ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz "https://github.com/Ryujinx/release-channel-master/releases/download/${LAT_V}/ryujinx-${LAT_V}-linux_x64.tar.gz" ; then
    echo "Successfully downloaded Ryujinx ${LAT_V}"
  else
    echo "Something went wrong, can't download Ryujinx ${LAT_V} continuing with ${CUR_V}!"
    rm -r ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
    LAT_V="${CUR_V}"
    touch ${DATA_DIR}/RyujinxVersion-${LAT_V}
    ERROR=true
  fi
  if [ "${ERROR}" != "true" ]; then
    tar -C ${DATA_DIR}/ --strip-components=1 -xf ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
    rm -f ${DATA_DIR}/Ryujinx-${LAT_V}.tar.gz
    touch ${DATA_DIR}/RyujinxVersion-${LAT_V}
  fi
elif [ "${CUR_V}" == "${LAT_V}" ]; then
  echo "Ryujinx ${CUR_V} up-to-date"
fi

echo "Starting Ryujinx ${LAT_V}"
chmod +x ${DATA_DIR}/Ryujinx
${DATA_DIR}/Ryujinx "$@"